Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(588)

Unified Diff: webrtc/p2p/base/turnserver_unittest.cc

Issue 2828223002: Delete method MessageQueue::set_socketserver (Closed)
Patch Set: Fix memory leak in SSLAdapterTestBase. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/p2p/base/turnserver_unittest.cc
diff --git a/webrtc/p2p/base/turnserver_unittest.cc b/webrtc/p2p/base/turnserver_unittest.cc
index a63670b21dbc406c0d46f038648da24f39f7fcd8..631eb46466eeb9c2bdf762d8c7fe667ad8aba1dd 100644
--- a/webrtc/p2p/base/turnserver_unittest.cc
+++ b/webrtc/p2p/base/turnserver_unittest.cc
@@ -21,7 +21,7 @@ namespace cricket {
class TurnServerConnectionTest : public testing::Test {
public:
- TurnServerConnectionTest() : vss_(&pss_), ss_scope_(&vss_) {}
+ TurnServerConnectionTest() : vss_(&pss_), thread_(&vss_) {}
void ExpectEqual(const TurnServerConnection& a,
const TurnServerConnection& b) {
@@ -41,8 +41,8 @@ class TurnServerConnectionTest : public testing::Test {
protected:
rtc::PhysicalSocketServer pss_;
rtc::VirtualSocketServer vss_;
- rtc::SocketServerScope ss_scope_;
- // Since this is constructed after |ss_scope_|, it will pick up |ss_scope_|'s
+ rtc::AutoSocketServerThread thread_;
+ // Since this is constructed after |thread_|, it will pick up |threads_|'s
// socket server.
rtc::BasicPacketSocketFactory socket_factory_;
};

Powered by Google App Engine
This is Rietveld 408576698